Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2248)

Unified Diff: chrome/browser/extensions/webstore_install_helper.h

Issue 9317074: Create an API around UtilityProcessHost and use that from chrome. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/webstore_install_helper.h
===================================================================
--- chrome/browser/extensions/webstore_install_helper.h (revision 120256)
+++ chrome/browser/extensions/webstore_install_helper.h (working copy)
@@ -6,12 +6,15 @@
#define CHROME_BROWSER_EXTENSIONS_WEBSTORE_INSTALL_HELPER_H_
#pragma once
-#include "content/browser/utility_process_host.h"
+#include <vector>
+
+#include "base/memory/scoped_ptr.h"
+#include "base/memory/weak_ptr.h"
+#include "content/public/browser/utility_process_host_client.h"
#include "content/public/common/url_fetcher_delegate.h"
#include "googleurl/src/gurl.h"
#include "third_party/skia/include/core/SkBitmap.h"
-class UtilityProcessHost;
class SkBitmap;
namespace base {
@@ -19,6 +22,10 @@
class ListValue;
}
+namespace content {
+class UtilityProcessHost;
+}
+
namespace net {
class URLRequestContextGetter;
}
@@ -27,7 +34,7 @@
// sending work to the utility process for parsing manifests and
// fetching/decoding icon data. Clients must implement the
// WebstoreInstallHelper::Delegate interface to receive the parsed data.
-class WebstoreInstallHelper : public UtilityProcessHost::Client,
+class WebstoreInstallHelper : public content::UtilityProcessHostClient,
public content::URLFetcherDelegate {
public:
class Delegate {
@@ -74,7 +81,7 @@
// Implementing the content::URLFetcherDelegate interface.
virtual void OnURLFetchComplete(const content::URLFetcher* source) OVERRIDE;
// Implementing pieces of the UtilityProcessHost::Client interface.
virtual bool OnMessageReceived(const IPC::Message& message) OVERRIDE;
// Message handlers.
@@ -104,7 +111,7 @@
scoped_ptr<content::URLFetcher> url_fetcher_;
net::URLRequestContextGetter* context_getter_; // Only usable on UI thread.
- base::WeakPtr<UtilityProcessHost> utility_host_;
+ base::WeakPtr<content::UtilityProcessHost> utility_host_;
// Flags for whether we're done doing icon decoding and manifest parsing.
bool icon_decode_complete_;
« no previous file with comments | « chrome/browser/extensions/webstore_inline_installer.cc ('k') | chrome/browser/extensions/webstore_install_helper.cc » ('j') | no next file with comments »
@@ -74,7 +81,7 @@
// Implementing the content::URLFetcherDelegate interface.
virtual void OnURLFetchComplete(const content::URLFetcher* source) OVERRIDE;
- // Implementing pieces of the UtilityProcessHost::Client interface.
+ // Implementing pieces of the UtilityProcessHostClient interface.
virtual bool OnMessageReceived(const IPC::Message& message) OVERRIDE;
// Message handlers.

Powered by Google App Engine
This is Rietveld 408576698